===============================
 Flask-IIIF v0.3.0 is released
===============================

Flask-IIIF v0.3.0 was released on August 17, 2017.

About
-----

Flask-IIIF is a Flask extension permitting easy integration with the
International Image Interoperability Framework (IIIF) API standards.

New features
------------

* Adds TIFF image support to the default config.
* Adds proper GIF resize.
* Adds optional Redis cache.

Installation
------------

   $ pip install Flask-IIIF

Documentation
-------------

   https://flask-iiif.readthedocs.io/en/v0.3.0

Homepage
--------

   https://github.com/inveniosoftware/flask-iiif

Happy hacking and thanks for flying Flask-IIIF.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware
|   URL: http://inveniosoftware.org
